Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(351)

Unified Diff: chrome/browser/thumbnails/thumbnailing_algorithm.h

Issue 1028393003: [Thumbnails] Specify copy size in Pixels, not DIPs (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: correct rebase Created 5 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/thumbnails/thumbnailing_algorithm.h
diff --git a/chrome/browser/thumbnails/thumbnailing_algorithm.h b/chrome/browser/thumbnails/thumbnailing_algorithm.h
index f75ab7c6ac2569dd47b4e63ed06355d6c88e0fa5..cf5a48755513a3e6214176938168a9ab8f7ad6b1 100644
--- a/chrome/browser/thumbnails/thumbnailing_algorithm.h
+++ b/chrome/browser/thumbnails/thumbnailing_algorithm.h
@@ -25,14 +25,15 @@ class ThumbnailingAlgorithm
ConsumerCallback;
// Provides information necessary to crop-and-resize image data from a source
// canvas of |source_size|. Auxiliary |scale_factor| helps compute the target
// thumbnail size. Parameters of the required copy operation are assigned to
// |clipping_rect| (cropping rectangle for the source canvas) and
// |target_size| (the size of the target bitmap).
// The return value indicates the type of clipping that will be done.
virtual ClipResult GetCanvasCopyInfo(const gfx::Size& source_size,
ui::ScaleFactor scale_factor,
gfx::Rect* clipping_rect,
- gfx::Size* target_size) const = 0;
+ gfx::Size* copy_size) const = 0;
// Invoked to produce a thumbnail image from a |bitmap| extracted by the
// callee from source canvas according to instructions provided by a call
@@ -51,6 +52,6 @@ class ThumbnailingAlgorithm
friend class base::RefCountedThreadSafe<ThumbnailingAlgorithm>;
};
-}
+} // namespace thumbnails
#endif // CHROME_BROWSER_THUMBNAILS_THUMBNAILING_ALGORITHM_H_
« no previous file with comments | « chrome/browser/thumbnails/simple_thumbnail_crop_unittest.cc ('k') | content/browser/compositor/delegated_frame_host.h » ('j') | no next file with comments »
@@ -25,14 +25,15 @@ class ThumbnailingAlgorithm
// Provides information necessary to crop-and-resize image data from a source
// canvas of |source_size|. Auxiliary |scale_factor| helps compute the target
- // thumbnail size. Parameters of the required copy operation are assigned to
- // |clipping_rect| (cropping rectangle for the source canvas) and
- // |target_size| (the size of the target bitmap).
- // The return value indicates the type of clipping that will be done.
+ // thumbnail size to be copied from the backing store, in pixels. Parameters
+ // of the required copy operation are assigned to |clipping_rect| (cropping
+ // rectangle for the source canvas) and |copy_size| (the size of the copied
+ // bitmap in pixels). The return value indicates the type of clipping that
+ // will be done.
virtual ClipResult GetCanvasCopyInfo(const gfx::Size& source_size,
ui::ScaleFactor scale_factor,

Powered by Google App Engine
This is Rietveld 408576698